Index: src/objects-inl.h |
diff --git a/src/objects-inl.h b/src/objects-inl.h |
index 302c0a4451a8769cfd388c87244bc9cfcfbaa3bb..24887a0efb6adba9fc902b813879b695997b7fb9 100644 |
--- a/src/objects-inl.h |
+++ b/src/objects-inl.h |
@@ -2610,10 +2610,12 @@ Code::Flags Code::ComputeFlags(Kind kind, |
PropertyType type, |
int argc, |
InlineCacheHolderFlag holder) { |
// Extra IC state is only allowed for monomorphic call IC stubs. |
ASSERT(extra_ic_state == kNoExtraICState || |
(kind == CALL_IC && (ic_state == MONOMORPHIC || |
- ic_state == MONOMORPHIC_PROTOTYPE_FAILURE))); |
+ ic_state == MONOMORPHIC_PROTOTYPE_FAILURE)) || |
+ (kind == STORE_IC)); |
// Compute the bit mask. |
int bits = kind << kFlagsKindShift; |
if (in_loop) bits |= kFlagsICInLoopMask; |
@@ -2610,10 +2610,12 @@ Code::Flags Code::ComputeFlags(Kind kind, |
int argc, |
InlineCacheHolderFlag holder) { |
- // Extra IC state is only allowed for monomorphic call IC stubs. |
+ // Extra IC state is only allowed for monomorphic call IC stubs |
+ // or for store IC stubs. |
ASSERT(extra_ic_state == kNoExtraICState || |
(kind == CALL_IC && (ic_state == MONOMORPHIC || |